@@ -34,12 +34,19 @@
 #include <libgda/gda-holder.h>
 #include <libgda/gda-log.h>
 #include <libgda/gda-util.h>
-#ifdef HAVE_FAM
-#include <fam.h>
-#include <glib.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
+#ifdef HAVE_GIO
+  #ifdef HAVE_FAM
+    #error Impossible to have GIO and FAM at the same time
+  #endif
+  #include <gio/gio.h>
+#else
+  #ifdef HAVE_FAM
+    #include <fam.h>
+    #include <glib.h>
+    #include <sys/types.h>
+    #include <sys/stat.h>
+    #include <unistd.h>
+  #endif
 #endif
 #ifdef G_OS_WIN32 
 #include <io.h>
@@ -101,9 +108,24 @@ enum {
 
 static GObjectClass *parent_class = NULL;
 
+#ifdef HAVE_GIO
+/*
+ * GIO static variables
+ */
+static GFileMonitor *mon_conf_user = NULL;
+static GFileMonitor *mon_conf_global = NULL;
+gulong user_notify_changes = 0;
+gulong global_notify_changes = 0;
+
+static void conf_file_changed (GFileMonitor *mon, GFile *file, GFile *other_file,
+			       GFileMonitorEvent event_type, gpointer data);
+static void lock_notify_changes (void);
+static void unlock_notify_changes (void);
+#endif
+
 #ifdef HAVE_FAM
 /*
- * FAM delcarations and static variables
+ * FAM declarations and static variables
  */
 static FAMConnection *fam_connection = NULL;
 static gint           fam_watch_id = 0;
@@ -134,6 +156,13 @@ gda_config_class_init (GdaConfigClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
+	/**
+	 * GdaConfig::dsn-added
+	 * @conf: the #GdaConfig object
+	 * @new_dsn: a #GdaDsnInfo
+	 *
+	 * Gets emitted whenever a new DSN has been defined
+	 */
 	gda_config_signals[DSN_ADDED] =
                 g_signal_new ("dsn-added",
                               G_TYPE_FROM_CLASS (object_class),
@@ -142,6 +171,13 @@ gda_config_class_init (GdaConfigClass *klass)
                               NULL, NULL,
                               _gda_marshal_VOID__POINTER,
                               G_TYPE_NONE, 1, G_TYPE_POINTER);
+	/**
+	 * GdaConfig::dsn-to-be-removed
+	 * @conf: the #GdaConfig object
+	 * @old_dsn: a #GdaDsnInfo
+	 *
+	 * Gets emitted whenever a DSN is about to be removed
+	 */
 	gda_config_signals[DSN_TO_BE_REMOVED] =
                 g_signal_new ("dsn-to-be-removed",
                               G_TYPE_FROM_CLASS (object_class),
@@ -150,6 +186,13 @@ gda_config_class_init (GdaConfigClass *klass)
                               NULL, NULL,
                               _gda_marshal_VOID__POINTER,
                               G_TYPE_NONE, 1, G_TYPE_POINTER);
+	/**
+	 * GdaConfig::dsn-removed
+	 * @conf: the #GdaConfig object
+	 * @old_dsn: a #GdaDsnInfo
+	 *
+	 * Gets emitted whenever a DSN has been removed
+	 */
 	gda_config_signals[DSN_REMOVED] =
                 g_signal_new ("dsn-removed",
                               G_TYPE_FROM_CLASS (object_class),
@@ -158,6 +201,13 @@ gda_config_class_init (GdaConfigClass *klass)
                               NULL, NULL,
                               _gda_marshal_VOID__POINTER,
                               G_TYPE_NONE, 1, G_TYPE_POINTER);
+	/**
+	 * GdaConfig::dsn-changed
+	 * @conf: the #GdaConfig object
+	 * @dsn: a #GdaDsnInfo
+	 *
+	 * Gets emitted whenever a DSN's definition has been changed
+	 */
 	gda_config_signals[DSN_CHANGED] =
                 g_signal_new ("dsn-changed",
                               G_TYPE_FROM_CLASS (object_class),
@@ -173,13 +223,15 @@ gda_config_class_init (GdaConfigClass *klass)
 
 	/* To translators: DSN stands for Data Source Name, it's a named connection string defined in ~/.libgda/config */
 	g_object_class_install_property (object_class, PROP_USER_FILE,
-                                         g_param_spec_string ("user-filename", _("File to use for per-user DSN list"), 
-							      NULL, NULL,
+                                         g_param_spec_string ("user-filename", NULL, 
+							      "File to use for per-user DSN list", 
+							      NULL, 
 							      (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	/* To translators: DSN stands for Data Source Name, it's a named connection string defined in $PREFIX/etc/libgda-4.0/config */
 	g_object_class_install_property (object_class, PROP_USER_FILE,
-                                         g_param_spec_string ("system-filename", _("File to use for system-wide DSN list"), 
-							      NULL, NULL,
+                                         g_param_spec_string ("system-filename", NULL,
+							      "File to use for system-wide DSN list", 
+							      NULL,
 							      (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	
 	object_class->constructor = gda_config_constructor;
@@ -369,6 +421,9 @@ save_config_file (gboolean is_system)
 		xmlSetProp (entry, BAD_CAST "value", BAD_CAST (info->description));
 	}
 
+#ifdef HAVE_GIO
+	lock_notify_changes ();
+#endif
 #ifdef HAVE_FAM
         fam_lock_notify ();
 #endif
@@ -381,6 +436,9 @@ save_config_file (gboolean is_system)
                         g_warning ("Error saving config data to '%s'", unique_instance->priv->system_file);
 	}
 	fflush (NULL);
+#ifdef HAVE_GIO
+	unlock_notify_changes ();
+#endif
 #ifdef HAVE_FAM
         fam_unlock_notify ();
 #endif
@@ -503,6 +561,22 @@ gda_config_constructor (GType type,
 		}
 
 		/* Setup file monitoring */
+#ifdef HAVE_GIO
+		GFile *gf;
+		gf = g_file_new_for_path (unique_instance->priv->user_file);
+		mon_conf_user = g_file_monitor_file (gf, G_FILE_MONITOR_NONE, NULL, NULL);
+		if (mon_conf_user)
+			g_signal_connect (G_OBJECT (mon_conf_user), "changed",
+					  G_CALLBACK (conf_file_changed), NULL);
+
+		gf = g_file_new_for_path (unique_instance->priv->system_file);
+		mon_conf_global = g_file_monitor_file (gf, G_FILE_MONITOR_NONE, NULL, NULL);
+		if (mon_conf_user)
+			g_signal_connect (G_OBJECT (mon_conf_global), "changed",
+					  G_CALLBACK (conf_file_changed), NULL);
+		
+#endif
+
 #ifdef HAVE_FAM
 		if (!fam_connection) {
 			/* FAM init */
@@ -513,7 +587,7 @@ gda_config_constructor (GType type,
 			g_print ("Using FAM to monitor configuration files changes.\n");
 #endif
 			fam_connection = g_malloc0 (sizeof (FAMConnection));
-			if (FAMOpen2 (fam_connection, "libgnomedb user") != 0) {
+			if (FAMOpen2 (fam_connection, "libgda user") != 0) {
 				g_print ("FAMOpen failed, FAMErrno=%d\n", FAMErrno);
 				g_free (fam_connection);
 				fam_connection = NULL;
@@ -879,7 +953,7 @@ gda_config_remove_dsn (const gchar *dsn_name, GError **error)
 }
 
 /**
- * gda_config_dsn_needs_auth
+ * gda_config_dsn_needs_authentication
  * @dsn_name: the name of a DSN, in the "[&lt;username&gt;[:&lt;password&gt;]@]&lt;DSN&gt;" format
  * 
  * Tells if the data source identified as @dsn_name needs any authentication. If a &lt;username&gt;
@@ -942,7 +1016,7 @@ gda_config_list_dsn (void)
  *
  * Get the number of defined DSN
  *
- * Return: the number of defined DSN
+ * Returns: the number of defined DSN
  */
 gint
 gda_config_get_nb_dsn (void)
@@ -959,7 +1033,7 @@ gda_config_get_nb_dsn (void)
 
 /**
  * gda_config_get_dsn_info_index
- * @dsn_name:
+ * @dsn_name: a DSN
  * 
  * Get the index (starting at 0) of the DSN named @dsn_name
  * 
@@ -986,7 +1060,7 @@ gda_config_get_dsn_info_index (const gchar *dsn_name)
 
 /**
  * gda_config_get_dsn_info_at_index
- * @index:
+ * @index: an index
  *
  * Get a pointer to a read-only #GdaDsnInfo at the @index position
  *
@@ -1026,10 +1100,9 @@ gda_config_can_modify_system_config (void)
 
 /**
  * gda_config_get_provider_info
- * @provider_name:
+ * @provider_name: a database provider
  *
  * Get some information about the a database provider (adaptator) named 
- * @provider_name
  *
  * Returns: a pointer to read-only #GdaProviderInfo structure, or %NULL if not found
  */
@@ -1061,7 +1134,7 @@ gda_config_get_provider_info (const gchar *provider_name)
 
 /**
  * gda_config_get_provider
- * @provider_name:
+ * @provider_name: a database provider
  * @error: a place to store errors, or %NULL
  *
  * Get a pointer to the session-wide #GdaServerProvider for the
@@ -1456,6 +1529,7 @@ load_providers_from_dir (const gchar *dirname, gboolean recurs)
 #endif
 			}
 		}
+		g_free (path);
 		g_module_close (handle);
 	}
 
@@ -1519,6 +1593,61 @@ internal_provider_free (InternalProvider *ip)
 /*
  * File monitoring actions
  */
+#ifdef HAVE_GIO
+static void
+conf_file_changed (GFileMonitor *mon, GFile *file, GFile *other_file,
+		   GFileMonitorEvent event_type, gpointer data)
+{
+	g_assert (unique_instance);
+
+	if (event_type != G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT)
+		return;
+
+	gboolean is_system = (mon == mon_conf_global) ? TRUE : FALSE;
+#ifdef GDA_DEBUG_NO
+	g_print ("Reloading config files (%s config has changed)\n", is_system ? "global" : "user");
+	GSList *list;
+	for (list = unique_instance->priv->dsn_list; list; list = list->next) {
+		GdaDsnInfo *info = (GdaDsnInfo *) list->data;
+		g_print ("[info %p]: %s/%s\n", info, info->provider, info->name);
+	}
+#endif
+	while (unique_instance->priv->dsn_list) {
+		GdaDsnInfo *info = (GdaDsnInfo *) unique_instance->priv->dsn_list->data;
+		g_signal_emit (unique_instance, gda_config_signals[DSN_TO_BE_REMOVED], 0, info);
+		unique_instance->priv->dsn_list = g_slist_remove (unique_instance->priv->dsn_list, info);
+		g_signal_emit (unique_instance, gda_config_signals[DSN_REMOVED], 0, info);
+		data_source_info_free (info);
+	}
+	
+	lock_notify_changes ();
+	if (unique_instance->priv->system_file)
+		load_config_file (unique_instance->priv->system_file, TRUE);
+	if (unique_instance->priv->user_file)
+		load_config_file (unique_instance->priv->user_file, FALSE);
+	unlock_notify_changes ();
+}
+
+static void
+lock_notify_changes (void)
+{
+	if (user_notify_changes != 0)
+		g_signal_handler_block (mon_conf_user, user_notify_changes);
+	if (global_notify_changes != 0)
+		g_signal_handler_block (mon_conf_global, global_notify_changes);
+}
+
+static void
+unlock_notify_changes (void)
+{
+	if (user_notify_changes != 0)
+		g_signal_handler_unblock (mon_conf_user, user_notify_changes);
+	if (global_notify_changes != 0)
+		g_signal_handler_unblock (mon_conf_global, global_notify_changes);
+}
+
+#endif
+
 #ifdef HAVE_FAM
 static gboolean
 fam_callback (GIOChannel *source, GIOCondition condition, gpointer data)
