@@ -39,7 +39,7 @@ extern GQuark gda_data_model_iter_error_quark (void);
 
 typedef enum
 {
-	GDA_DATA_MODEL_ITER_WHAT_ERROR
+	GDA_DATA_MODEL_ITER_COLUMN_OUT_OF_RANGE_ERROR
 } GdaDataModelIterError;
 
 
@@ -55,7 +55,6 @@ struct _GdaDataModelIterClass
 {
 	GdaSetClass                parent_class;
 
-	gboolean                (* row_to_change)    (GdaDataModelIter *iter, gint row);
 	void                    (* row_changed)      (GdaDataModelIter *iter, gint row);
 	void                    (* end_of_data)      (GdaDataModelIter *iter);
 };
@@ -64,18 +63,21 @@ GType             gda_data_model_iter_get_type             (void) G_GNUC_CONST;
 
 const GValue     *gda_data_model_iter_get_value_at         (GdaDataModelIter *iter, gint col);
 const GValue     *gda_data_model_iter_get_value_for_field  (GdaDataModelIter *iter, const gchar *field_name);
+gboolean          gda_data_model_iter_set_value_at         (GdaDataModelIter *iter, gint col, 
+							    const GValue *value, GError **error);
 
-gboolean          gda_data_model_iter_set_at_row           (GdaDataModelIter *iter, gint row);
+gboolean          gda_data_model_iter_move_to_row          (GdaDataModelIter *iter, gint row);
 gboolean          gda_data_model_iter_move_next            (GdaDataModelIter *iter);
 gboolean          gda_data_model_iter_move_prev            (GdaDataModelIter *iter);
 gint              gda_data_model_iter_get_row              (GdaDataModelIter *iter);
 
-gboolean          gda_data_model_iter_can_be_moved         (GdaDataModelIter *iter);
 void              gda_data_model_iter_invalidate_contents  (GdaDataModelIter *iter);
 gboolean          gda_data_model_iter_is_valid             (GdaDataModelIter *iter);
 
 GdaHolder        *gda_data_model_iter_get_holder_for_field (GdaDataModelIter *iter, gint col);
 
+#define gda_data_model_iter_move_at_row gda_data_model_iter_move_to_row
+
 G_END_DECLS
 
 #endif
