@@ -22,7 +22,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <glib/gmessages.h>
+#include <glib.h>
 #include <libgda/gda-server-provider.h>
 #include <libgda/gda-server-provider-extra.h>
 #include <libgda/gda-server-provider-private.h>
@@ -500,7 +500,7 @@ gda_server_provider_create_operation (GdaServerProvider *provider, GdaConnection
 					value = gda_holder_get_value (GDA_HOLDER (list->data));
 					if (value)
 						str = gda_value_stringify (value);
-					node = xmlNewChild (top, NULL, BAD_CAST "op_data", BAD_CAST str);
+					node = xmlNewTextChild (top, NULL, BAD_CAST "op_data", BAD_CAST str);
 					g_free (str);
 					xmlSetProp (node, BAD_CAST "path", BAD_CAST id);
 				}
@@ -647,7 +647,7 @@ gda_server_provider_supports_feature (GdaServerProvider *provider, GdaConnection
 }
 
 /**
- * gda_server_provider_get_data_handler_gtype
+ * gda_server_provider_get_data_handler_g_type
  * @provider: a server provider.
  * @cnc: a #GdaConnection object, or %NULL
  * @for_type: a #GType
@@ -657,7 +657,7 @@ gda_server_provider_supports_feature (GdaServerProvider *provider, GdaConnection
  * Returns: a #GdaDataHandler, or %NULL if the provider does not support the requested @for_type data type 
  */
 GdaDataHandler *
-gda_server_provider_get_data_handler_gtype (GdaServerProvider *provider, GdaConnection *cnc, GType for_type)
+gda_server_provider_get_data_handler_g_type (GdaServerProvider *provider, GdaConnection *cnc, GType for_type)
 {
 	GdaDataHandler *retval;
 	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (provider), NULL);
@@ -741,24 +741,29 @@ gda_server_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConne
  * @provider: a server provider.
  * @cnc: a #GdaConnection object, or %NULL
  * @string: the SQL string to convert to a value
- * @prefered_type: a #GType, or G_TYPE_INVALID
+ * @preferred_type: a #GType, or G_TYPE_INVALID
+ * @dbms_type: place to get the actual database type used if the conversion succeeded, or %NULL
  *
  * Use @provider to create a new #GValue from a single string representation. 
  *
- * The @prefered_type can optionally ask @provider to return a #GValue of the requested type 
+ * The @preferred_type can optionally ask @provider to return a #GValue of the requested type 
  * (but if such a value can't be created from @string, then %NULL is returned); 
  * pass G_TYPE_INVALID if any returned type is acceptable.
  *
  * The returned value is either a new #GValue or %NULL in the following cases:
- * - @string cannot be converted to @prefered_type type
- * - the provider does not handle @prefered_type
+ * - @string cannot be converted to @preferred_type type
+ * - the provider does not handle @preferred_type
  * - the provider could not make a #GValue from @string
  *
+ * If @dbms_type is not %NULL, then if will contain a constant string representing
+ * the database type used for the conversion if the conversion was successfull, or %NULL
+ * otherwise.
+ *
  * Returns: a new #GValue, or %NULL
  */
 GValue *
 gda_server_provider_string_to_value (GdaServerProvider *provider,  GdaConnection *cnc, const gchar *string, 
-				     GType prefered_type, gchar **dbms_type)
+				     GType preferred_type, gchar **dbms_type)
 {
 	GValue *retval = NULL;
 	GdaDataHandler *dh;
@@ -767,12 +772,15 @@ gda_server_provider_string_to_value (GdaServerProvider *provider,  GdaConnection
 	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (provider), NULL);
 	g_return_val_if_fail (!cnc || GDA_IS_CONNECTION (cnc), NULL);
 
+	if (dbms_type)
+		*dbms_type = NULL;
+
 	if (cnc)
 		gda_lockable_lock ((GdaLockable*) cnc);
-	if (prefered_type != G_TYPE_INVALID) {
-		dh = gda_server_provider_get_data_handler_gtype (provider, cnc, prefered_type);
+	if (preferred_type != G_TYPE_INVALID) {
+		dh = gda_server_provider_get_data_handler_g_type (provider, cnc, preferred_type);
 		if (dh) {
-			retval = gda_data_handler_get_value_from_sql (dh, string, prefered_type);
+			retval = gda_data_handler_get_value_from_sql (dh, string, preferred_type);
 			if (retval) {
 				gchar *tmp;
 				
@@ -784,7 +792,7 @@ gda_server_provider_string_to_value (GdaServerProvider *provider,  GdaConnection
 				else {
 					if (dbms_type)
 						*dbms_type = (gchar *) gda_server_provider_get_default_dbms_type (provider, 
-														  cnc, prefered_type);
+														  cnc, preferred_type);
 				}
 				
 				g_free (tmp);
@@ -816,7 +824,7 @@ gda_server_provider_string_to_value (GdaServerProvider *provider,  GdaConnection
 				 GDA_TYPE_BINARY};
 		
 		for (i = 0; !retval && (i <= (sizeof(types)/sizeof (GType)) - 1); i++) {
-			dh = gda_server_provider_get_data_handler_gtype (provider, cnc, types [i]);
+			dh = gda_server_provider_get_data_handler_g_type (provider, cnc, types [i]);
 			if (dh) {
 				retval = gda_data_handler_get_value_from_sql (dh, string, types [i]);
 				if (retval) {
@@ -868,9 +876,9 @@ gda_server_provider_value_to_sql_string (GdaServerProvider *provider,
 
 	if (cnc)
 		gda_lockable_lock ((GdaLockable*) cnc);
-	dh = gda_server_provider_get_data_handler_gtype (provider, cnc, G_VALUE_TYPE (from));
+	dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_VALUE_TYPE (from));
 	if (dh)
-		return gda_data_handler_get_sql_from_value (dh, from);
+		retval = gda_data_handler_get_sql_from_value (dh, from);
 	if (cnc)
 		gda_lockable_unlock ((GdaLockable*) cnc);
 	return retval;
