@@ -28,16 +28,13 @@
 #include <string.h>
 #include <stdlib.h>
 #include <time.h>
-#include <glib/gdate.h>
-#include <glib/gmessages.h>
-#include <glib/gstrfuncs.h>
-#include <glib/gstring.h>
-#include <glib/gi18n-lib.h>
 #include <libgda/gda-value.h>
 #include <libgda/gda-blob-op.h>
 #include <libgda/gda-util.h>
 #include <libxml/parser.h>
 #include <libxml/tree.h>
+#define __GDA_INTERNAL__
+#include "dir-blob-op.h"
 
 #define l_g_value_unset(val) G_STMT_START{ if (G_IS_VALUE (val)) g_value_unset (val); }G_STMT_END
 #ifdef G_OS_WIN32
@@ -564,8 +561,8 @@ gda_geometricpoint_free (gpointer boxed)
 /* 
  * Register the GdaValueList type in the GType system 
  */
-gpointer gda_value_list_copy (gpointer boxed);
-void gda_value_list_free (gpointer boxed);
+static gpointer gda_value_list_copy (gpointer boxed);
+static void gda_value_list_free (gpointer boxed);
 
 static void 
 list_to_string (const GValue *src, GValue *dest) 
@@ -623,7 +620,7 @@ gda_value_list_get_type(void)
 	return type;
 }
 
-gpointer 
+static gpointer 
 gda_value_list_copy (gpointer boxed)
 {
 	GList *list = NULL;
@@ -639,7 +636,7 @@ gda_value_list_copy (gpointer boxed)
 	return list;
 }
 
-void
+static void
 gda_value_list_free (gpointer boxed)
 {
 	GList *l = (GList*) boxed;
@@ -762,7 +759,7 @@ gda_numeric_copy (gpointer boxed)
 
 /**
  * gda_numeric_free
- * @boxed:
+ * @boxed: a #GdaNumeric pointer
  *
  * Deallocates all memory associated to the given @boxed
  */
@@ -1114,7 +1111,7 @@ gda_value_new_binary (const guchar *val, glong size)
  * @val: value to set for the new #GValue.
  * @size: the size of the memory pool pointer to by @val.
  *
- * Makes a new #GValue of type #GDA_TYPE_BLOB with value @val.
+ * Makes a new #GValue of type #GDA_TYPE_BLOB with the data contained by @val.
  *
  * Returns: the newly created #GValue.
  */
@@ -1122,20 +1119,44 @@ GValue *
 gda_value_new_blob (const guchar *val, glong size)
 {
 	GValue *value;
-	GdaBlob blob;
+	GdaBlob *blob;
 	GdaBinary *bin;
 
+	blob = g_new0 (GdaBlob, 1);
 	bin = (GdaBinary*)(&blob);
-
-        /* We use the const on the function parameter to make this clearer, 
-	 * but it would be awkward to keep the const in the struct.
-         */
-        bin->data = (guchar*)val;
+	bin->data = g_new (guchar, size);
+        memcpy ((gpointer) bin->data, (gpointer) val, size);
         bin->binary_length = size;
-	blob.op = NULL;
+	blob->op = NULL;
 
         value = g_new0 (GValue, 1);
-        gda_value_set_blob (value, &blob);
+	g_value_init (value, GDA_TYPE_BLOB);
+        g_value_take_boxed (value, blob);
+
+        return value;
+}
+
+/**
+ * gda_value_new_blob
+ * @val: value to set for the new #GValue.
+ * @size: the size of the memory pool pointer to by @val.
+ *
+ * Makes a new #GValue of type #GDA_TYPE_BLOB with the data contained by @val.
+ *
+ * Returns: the newly created #GValue.
+ */
+GValue *
+gda_value_new_blob_from_file (const gchar *filename)
+{
+	GValue *value;
+	GdaBlob *blob;
+
+	blob = g_new0 (GdaBlob, 1);
+	blob->op = gda_dir_blob_op_new (filename);
+
+        value = g_new0 (GValue, 1);
+	g_value_init (value, GDA_TYPE_BLOB);
+        g_value_take_boxed (value, blob);
 
         return value;
 }
@@ -1160,8 +1181,8 @@ gda_value_new_timestamp_from_timet (time_t val)
         ltm = localtime ((const time_t *) &val);
         if (ltm) {
                 GdaTimestamp tstamp;
-                tstamp.year = ltm->tm_year;
-                tstamp.month = ltm->tm_mon;
+                tstamp.year = ltm->tm_year + 1900;
+                tstamp.month = ltm->tm_mon + 1;
                 tstamp.day = ltm->tm_mday;
                 tstamp.hour = ltm->tm_hour;
                 tstamp.minute = ltm->tm_min;
@@ -2632,5 +2653,8 @@ gda_blob_to_string (GdaBlob *blob, guint maxlen)
 gboolean
 gda_string_to_blob (const gchar *str, GdaBlob *blob)
 {
-	return gda_string_to_binary (str, (GdaBinary*) blob);
+	gboolean retval;
+	retval = gda_string_to_binary (str, (GdaBinary*) blob);
+	blob->op = NULL;
+	return retval;
 }
