@@ -1,6 +1,6 @@
 /* gda-handler-type.c
  *
- * Copyright (C) 2005 - 2008 Vivien Malerba
+ * Copyright (C) 2005 - 2009 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -36,8 +36,6 @@ static GValue      *gda_handler_type_get_value_from_sql     (GdaDataHandler *dh,
 							     GType type);
 static GValue      *gda_handler_type_get_value_from_str     (GdaDataHandler *dh, const gchar *sql, 
 							     GType type);
-static guint        gda_handler_type_get_nb_g_types       (GdaDataHandler *dh);
-static GType        gda_handler_type_get_g_type_index     (GdaDataHandler *dh, guint index);
 static gboolean     gda_handler_type_accepts_g_type       (GdaDataHandler * dh, GType type);
 
 static const gchar *gda_handler_type_get_descr              (GdaDataHandler *dh);
@@ -94,9 +92,7 @@ gda_handler_type_data_handler_init (GdaDataHandlerIface *iface)
 	iface->get_value_from_sql = gda_handler_type_get_value_from_sql;
 	iface->get_value_from_str = gda_handler_type_get_value_from_str;
 	iface->get_sane_init_value = NULL;
-	iface->get_nb_g_types = gda_handler_type_get_nb_g_types;
 	iface->accepts_g_type = gda_handler_type_accepts_g_type;
-	iface->get_g_type_index = gda_handler_type_get_g_type_index;
 	iface->get_descr = gda_handler_type_get_descr;
 }
 
@@ -176,10 +172,10 @@ gda_handler_type_get_sql_from_value (GdaDataHandler *iface, const GValue *value)
 
 	if (value) {
 		GTypeQuery tq;
-		g_type_query (g_value_get_ulong (value), &tq);
+		g_type_query (g_value_get_gtype (value), &tq);
 		if (tq.type != 0) {
 			const gchar *str;
-			str = gda_g_type_to_string (g_value_get_ulong (value));
+			str = gda_g_type_to_string (g_value_get_gtype (value));
 			retval = g_strdup_printf ("'%s'", str);
 		}
 		else
@@ -204,9 +200,9 @@ gda_handler_type_get_str_from_value (GdaDataHandler *iface, const GValue *value)
 	if (value) {
 		GTypeQuery tq;
        
-		g_type_query (g_value_get_ulong (value), &tq);
+		g_type_query (g_value_get_gtype (value), &tq);
 		if (tq.type != 0)
-			retval = g_strdup (gda_g_type_to_string (g_value_get_ulong (value)));
+			retval = g_strdup (gda_g_type_to_string (g_value_get_gtype (value)));
 		else
 			retval = g_strdup (NULL); /* FIXME: return NULL instead because of the error? */
 	}
@@ -235,7 +231,7 @@ gda_handler_type_get_value_from_sql (GdaDataHandler *iface, const gchar *sql, GT
 			type = gda_g_type_from_string (str+1);
 			g_free (str);
 			value = g_value_init (g_new0 (GValue, 1), G_TYPE_GTYPE);
-			g_value_set_ulong (value, type);
+			g_value_set_gtype (value, type);
 		}
 	}
 	else
@@ -256,24 +252,11 @@ gda_handler_type_get_value_from_str (GdaDataHandler *iface, const gchar *str, GT
 
 	vtype = gda_g_type_from_string (str);
 	value = g_value_init (g_new0 (GValue, 1), G_TYPE_GTYPE);
-	g_value_set_ulong (value, vtype);
+	g_value_set_gtype (value, vtype);
 
 	return value;
 }
 
-static guint
-gda_handler_type_get_nb_g_types (GdaDataHandler *iface)
-{
-	GdaHandlerType *hdl;
-
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_TYPE (iface), 0);
-	hdl = GDA_HANDLER_TYPE (iface);
-	g_return_val_if_fail (hdl->priv, 0);
-
-	return hdl->priv->nb_g_types;
-}
-
-
 static gboolean
 gda_handler_type_accepts_g_type (GdaDataHandler *iface, GType type)
 {
@@ -295,19 +278,6 @@ gda_handler_type_accepts_g_type (GdaDataHandler *iface, GType type)
 	return found;
 }
 
-static GType
-gda_handler_type_get_g_type_index (GdaDataHandler *iface, guint index)
-{
-	GdaHandlerType *hdl;
-
-	g_return_val_if_fail (iface && GDA_IS_HANDLER_TYPE (iface), G_TYPE_INVALID);
-	hdl = GDA_HANDLER_TYPE (iface);
-	g_return_val_if_fail (hdl->priv, G_TYPE_INVALID);
-	g_return_val_if_fail (index < hdl->priv->nb_g_types, G_TYPE_INVALID);
-
-	return hdl->priv->valid_g_types[index];
-}
-
 static const gchar *
 gda_handler_type_get_descr (GdaDataHandler *iface)
 {
