@@ -198,7 +198,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 				GdaDataHandler *dh;
 				gchar *str;
 				
-				dh = gda_server_provider_get_data_handler_gtype (provider, cnc, G_TYPE_STRING);
+				dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 				str = gda_data_handler_get_sql_from_value (dh, value);
 				if (str) {
 					if (*str) {
@@ -250,7 +250,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 				node = gda_server_operation_get_node_info (op, "/FKEY_S/%d/FKEY_FIELDS_A", i);
 				if (!node || ((nbfields = gda_data_model_get_n_rows (node->model)) == 0)) {
 					allok = FALSE;
-					g_set_error (error, 0, 0, _("No field specified in foreign key constraint"));
+					g_set_error (error, 0, 0, "%s", _("No field specified in foreign key constraint"));
 				}
 				else {
 					for (j = 0; j < nbfields; j++) {
@@ -262,7 +262,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 							g_string_append (string, g_value_get_string (value));
 						else {
 							allok = FALSE;
-							g_set_error (error, 0, 0, 
+							g_set_error (error, 0, 0, "%s",  
 								     _("Empty field specified in foreign key constraint"));
 						}
 					}
@@ -273,7 +273,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 					g_string_append (string, g_value_get_string (value));
 				else {
 					allok = FALSE;
-					g_set_error (error, 0, 0, _("No referenced table specified in foreign key constraint"));
+					g_set_error (error, 0, 0, "%s", _("No referenced table specified in foreign key constraint"));
 				}
 
 				g_string_append (string, " (");
@@ -286,7 +286,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 						g_string_append (string, g_value_get_string (value));
 					else {
 						allok = FALSE;
-						g_set_error (error, 0, 0, 
+						g_set_error (error, 0, 0, "%s",  
 							     _("Empty referenced field specified in foreign key constraint"));
 					}
 				}
@@ -308,7 +308,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 
 	if (!hasfields) {
 		allok = FALSE;
-		g_set_error (error, 0, 0, _("Table to create must have at least one row"));
+		g_set_error (error, 0, 0, "%s", _("Table to create must have at least one row"));
 	}
 
 	/* other options */
@@ -352,7 +352,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 			GdaDataHandler *dh;
 			gchar *str;
 
-			dh = gda_server_provider_get_data_handler_gtype (provider, cnc, G_TYPE_STRING);
+			dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 			str = gda_data_handler_get_sql_from_value (dh, value);
 			g_string_append (string, " COMMENT = ");
 			g_string_append (string, str);
@@ -380,7 +380,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 			GdaDataHandler *dh;
 			gchar *str;
 
-			dh = gda_server_provider_get_data_handler_gtype (provider, cnc, G_TYPE_STRING);
+			dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 			str = gda_data_handler_get_sql_from_value (dh, value);
 			g_string_append (string, " PASSWORD = ");
 			g_string_append (string, str);
@@ -418,7 +418,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 			GdaDataHandler *dh;
 			gchar *str;
 
-			dh = gda_server_provider_get_data_handler_gtype (provider, cnc, G_TYPE_STRING);
+			dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 			str = gda_data_handler_get_sql_from_value (dh, value);
 			g_string_append (string, " DATA_DIRECTORY = ");
 			g_string_append (string, str);
@@ -431,7 +431,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 			GdaDataHandler *dh;
 			gchar *str;
 
-			dh = gda_server_provider_get_data_handler_gtype (provider, cnc, G_TYPE_STRING);
+			dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 			str = gda_data_handler_get_sql_from_value (dh, value);
 			g_string_append (string, " INDEX_DIRECTORY = ");
 			g_string_append (string, str);
@@ -576,7 +576,7 @@ gda_mysql_render_ADD_COLUMN (GdaServerProvider *provider, GdaConnection *cnc,
 		GdaDataHandler *dh;
 		gchar *str;
 		
-		dh = gda_server_provider_get_data_handler_gtype (provider, cnc, G_TYPE_STRING);
+		dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 		str = gda_data_handler_get_sql_from_value (dh, value);
 		if (str) {
 			if (*str) {
@@ -778,7 +778,7 @@ gda_mysql_render_CREATE_VIEW (GdaServerProvider *provider, GdaConnection *cnc,
 				g_string_append_c (string, ' ');
 			}
 			else {
-				g_set_error (error, 0, 0, _("Incorrect specified column name"));
+				g_set_error (error, 0, 0, "%s", _("Incorrect specified column name"));
 				allok = FALSE;
 			}
 		}
